import QtQuick 1.1
import StatisticManager 1.0
import "../Globals.js" as Globals

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24
    property int topOffset: -150
    property int itemSpacing: 5
    property int itemColumnSpacing: 50
    property string cursorState: "clear" // clear is the only state

    function clearMileage() {
        statisticManager.resetMileage()
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsStatistics")
            diagnostics_screen.item.unselectScreen()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsStatistics")
            if (cursorState === "clear")
                root.clearMileage()
        }
    }

    Column{
        id: labels
        spacing: itemSpacing
        anchors.left: parent.left
        anchors.leftMargin: 200
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{
            text: qsTr("Run Hours") + application.emptyString
            font.pointSize: fontSize
        }

        Text{
            text: qsTr("Machine Distance") + application.emptyString
            font.pointSize: fontSize
        }

        Text{
            text: qsTr("Distance") + application.emptyString
            font.pointSize: fontSize
        }


//        Text{
//            text: qsTr("Average Speed") + application.emptyString
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

//        Text{
//            text: qsTr("Max Speed") + application.emptyString
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }


    }
    Column{
        id:values
        spacing: itemSpacing
        anchors.left: labels.right
        anchors.leftMargin: 200
        anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: topOffset

        Text{

            text: Number(statisticManager.runHours/3600).toFixed(1) + " " + qsTr("Hours") + application.emptyString
            font.pointSize: fontSize
        }

        Text{
            text: {
                if(options.metricUnits)
                    return Globals.mileToKm(statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("KM")
                else
                    return (statisticManager.totalDistance/100).toFixed(2) + " " + qsTr("miles") + application.emptyString
            }
            font.pointSize: fontSize
        }

        Text{
            id: tripMilesValue
            text: {
                if(options.metricUnits)
                    return Globals.mileToKm(statisticManager.mileage/100).toFixed(2) + " " + qsTr("KM")
                else
                    return (statisticManager.mileage/100).toFixed(2) + " " + qsTr("miles") + application.emptyString
            }
            font.pointSize: fontSize
        }

//        Text{
//            text: (statisticManager.averageSpeed / 10).toFixed(1)
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

//        Text{
//            text: (statisticManager.maxSpeed / 10).toFixed(1)
//            font.pointSize: fontSize
//            visible: isTreadmill
//        }

    }
    ImageButton{
        id: clearButton
        wrapWidth: 150
        label: qsTr("CLEAR MILEAGE") + application.emptyString
        upimage:"./graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"./graphics/200/TRU_200_other_small_Button_Down.png"
        label_under: true
        label_y_offset: -3
        label_color: "black"
        font.pointSize: 14
        y: tripMilesValue.y + height - 20
        anchors { left: values.right ; leftMargin: 40 }
        onClicked: root.clearMileage()
    }

    Image {
        source: "../graphics/tft/NAV_selector_2.png"
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "clear"
        anchors.centerIn: clearButton
        anchors.horizontalCenterOffset: -25
        z: clearButton.z - 1
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
