import QtQuick 1.1
import Busy 1.0

Item {
    id: root

    property real hrFillPercent: _hrFillPercent()
    property int heartRate: 0
    property int heartRateMax: 220
    property int targetHeartRate: 0
    property bool showTargetHeartRate: false

    property bool _hr_valid: brainboard.heartRateAvailable

    property alias hrCruiseEnabled: hrCruiseButton.isDown
    property bool cruiseAllowed: false
    property bool dialogVisible: false
    property string hrDeviceMAC: null


    function _hrFillPercent() {
        var hrPercent = root.heartRate / root.heartRateMax
        var ret = 0.0
        if (hrPercent <= 0.3) {
            ret = 0.0
        } else if (hrPercent > 0.3 && hrPercent <= 0.6) {
            ret = 0.25 * ((hrPercent - 0.3) / 0.3)
        } else if (hrPercent > 0.6 && hrPercent <= 0.75) {
            ret = 0.25 + (0.25 * ((hrPercent - 0.6) / 0.15))
        } else if (hrPercent > 0.75 && hrPercent <= 0.85) {
            ret = 0.5 + (0.25 * ((hrPercent - 0.75) / 0.10))
        } else if (hrPercent > 0.85) {
            ret = 0.75 + (0.25 * ((hrPercent - 0.85) / 0.15))
        }
        return ret
    }

    Image {
        id: hrBackground

        anchors.top: parent.top
        anchors.topMargin: -4
        anchors.horizontalCenter: parent.horizontalCenter
        width: 987
        height: 304
        source: "graphics/224/224_Data_Curved_Window.png"
    }

    Image {
        id: hrMeterBackground

        anchors.horizontalCenter: hrBackground.horizontalCenter
        anchors.horizontalCenterOffset: -2
        y: 34
        source: "graphics/224/224_Data_Color_Meter_Dark.png"
    }

    Item {
        id: hrMeterFill

        anchors.left: hrMeterBackground.left
        y: 34
        width: hrFillPercent * 502
        height: 113
        clip: true

        Image {
            id: hrMeterFillColor
            source: "graphics/224/224_Data_Color_Meter_Light.png"
        }
    }

    Image {
        id: hrMeterRule
        anchors.horizontalCenter: hrBackground.horizontalCenter
        anchors.horizontalCenterOffset: -2
        y: 34
        source: "graphics/224/224_Data_Color_Meter_Rule.png"
    }

    Image{
        id: hrMeterText
        anchors.top: hrMeterRule.top
        anchors.topMargin: -15
        anchors.right: hrMeterRule.right
        anchors.rightMargin: 10
        source: "graphics/224/HRmeter_text_ENG.png"
    }

    ImageButton {
        id: hrCruiseButton

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -90
        anchors.verticalCenter: hrValue.verticalCenter
        anchors.verticalCenterOffset: 4
        fontsize: 12
        downimage: "graphics/224/Data_HRC_Cruise_Down.png"
        upimage: "graphics/224/Data_HRC_Cruise_Up.png"
        label: qsTr("CRUISE") + application.emptyString
        label_color: "black"
        label_y_offset: 30
        mouseAreaScale: 2.0
        toggle: true
        enabled: root.cruiseAllowed
        disabledimage: "graphics/224/Data_HRC_Cruise_Disabled.png"
    }

    Text {
        id: hrValue

        anchors.horizontalCenter: parent.horizontalCenter
        y: 93
        color: "black"
        font.pointSize: 32
        font.bold: true
        // display value if in range between 20 and 251, else display --
        text: _hr_valid ? root.heartRate : "--"
        visible: !bluetoothLEAdapter.connecting
    }

    Text {
        id: hrUnitsLabel

        anchors.horizontalCenter: parent.horizontalCenter
        y: text.length > 3 ? 137 : 144
        color: "black"
        font.pointSize: text.length > 3 ? 9 : 11
        font.bold: true
        width: 150
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        text: qsTr("BPM") + application.emptyString
    }

    BeatingHeart {
        id: hrIcon

        visible: _hr_valid
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 60
        anchors.verticalCenter: hrValue.verticalCenter
        anchors.verticalCenterOffset: 4
    }

    Text {
        id: targetHRValue

        anchors.horizontalCenter: hrIcon.right
        anchors.horizontalCenterOffset: 18
        anchors.verticalCenter: hrIcon.verticalCenter
        color: "black"
        font.pointSize: 18
        font.bold: true
        text: root.targetHeartRate
        visible: root.showTargetHeartRate || hrCruiseButton.isDown
    }


    Text {
        id: targetHRUnitsLabel

        anchors.horizontalCenter: targetHRValue.horizontalCenter
        anchors.verticalCenter: targetHRValue.verticalCenter
        anchors.verticalCenterOffset: 20
        color: "black"
        font.pointSize: 9
        font.bold: true
        text: qsTr("TARGET") + application.emptyString
        visible: root.showTargetHeartRate || hrCruiseButton.isDown
    }
    ImageButton {
        id: blueToothIcon
        // pre-release-1.3
        visible: false
        //

        anchors.left: targetHRValue.right

        anchors.leftMargin: 0
        anchors.verticalCenter: targetHRValue.verticalCenter
        upimage: "graphics/Bluetooth/Bluetooth_icon_small.png"
        downimage: "graphics/Bluetooth/bluetooth_blue.png"
        //        z:1
        onClicked: {
            bleHeartDialog.show()
            bleHeartDialog.state= "scanning"
            bluetoothLEAdapter.scan()

        }



        enabled:true

    }

    BusyIndicator {
        id: busyIndicator
        width: 50
        height: 50
        anchors.horizontalCenter: hrValue.horizontalCenter
        anchors.verticalCenter: hrValue.verticalCenter
        visible: bluetoothLEAdapter.connecting
        RotationAnimation
        {
            target: busyIndicator
            property: "rotation" // Suppress a warninge
            from: 0
            to: 360
            direction: RotationAnimation.Clockwise
            duration: 1000
            loops: Animation.Infinite
            running: bluetoothLEAdapter.connecting
        }

    }

    BlueToothHeartRate {
        id: bluetoothLEAdapter
    }

    Connections{
        target: bluetoothLEAdapter

        onScanned: {
            console.log(" scanned signal caught in HR panel")
            for(var j=0;j<bluetoothLEAdapter.hrMonitors.count;j++) {
                console.log("j=" +j)
                console.log(bluetoothLEAdapter.hrMonitors.get(j).name)
            }
             bleHeartDialog.state = "monitorList"
        }

        onHaveBluetoothHrValue:{
            if(isNaN(bluetoothLEAdapter.heartrate)){
                //_hr_valid=false
                bluetoothLEAdapter.connecting=false
                console.log("Invalid HR detected")
            } else {
                _hr_valid =true
                bluetoothLEAdapter.connecting=false
            }
            root.heartRate=bluetoothLEAdapter.heartrate
            bleHeartDialog.state = "monitoring"

        }
        onHrConnectionFailed: {
            bleHeartDialog.state = "idle"
        }

//        onConnectedChanged:{
//            if(connected){
//                bleHeartDialog.state = "idle"
//            }else{
//                bleHeartDialog.state = "disconnecting"
//            }
//        }

        onHrDisconnecting:{
            console.debug("BLE disconnecting signal received, deviceMAC=" + bluetoothLEAdapter.deviceMAC)
            // Only disconnect if we are monitoring
            if((bleHeartDialog.state!=="idle") && (bluetoothLEAdapter.deviceMAC!=="NULL" )){
                bleHeartDialog.state = "disconnecting"
                bluetoothLEAdapter.hrDisconnect(bluetoothLEAdapter.deviceMAC,bluetoothLEAdapter.hrHandle)
            }
            else {
                console.debug("bleHeartDialog.state= " +
                              bleHeartDialog.state +
                              " bluetoothLEAdapter.deviceMAC =" +
                              bluetoothLEAdapter.deviceMAC )
            }
        }

        onHrDisconnectingComplete:{
            console.debug("disconnectingComplete signal received")
            bleHeartDialog.state = "idle"
        }
    }


    Connections{
        target: workoutScreen
        onWorkoutStopped: {
            bluetoothLEAdapter.hrDisconnecting()
            console.log("Sendiing disconnect signal to HR")
        }

    }


    ModalDialog {
        id: bleHeartDialog
        anchors.verticalCenterOffset: 100
        visible: dialogVisible
        isTop: true
        state: "idle"
        isTransparent: true

        anchors {verticalCenter: parent.verticalCenter; horizontalCenter: parent.horizontalCenter}

        dismissable: true
        // onDismissed:
        // onTimedOut:


        BorderImage {   // pop-up dialog background
            id: btStatusDialogborder

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: hrBackground.width * 0.8
            height: width / 2

            source: "graphics/Pop_Up_Lrg_Grey.png"
            border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

            Text {
                id: btScanningText
                visible: false
                anchors.top: parent.top
                anchors.topMargin: 50
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                //height: parent.height * 0.5
                color: "white"
                text: "SCANNING FOR BLUETOOTH DEVICES..."
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.10
            }

            Item {
                id: scanningAnimation
                height: 58
                width: 108
                anchors.top: btScanningText.bottom
                anchors.topMargin: 50
                anchors.horizontalCenter: parent.horizontalCenter
                Image{
                    id: scanningBluetoothWave
                    property int opacityInteger: 0
                    anchors.fill: parent
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "graphics/Bluetooth/Bluetooth_waves.png"
                    opacity: opacityInteger / 100.0
                    NumberAnimation on opacityInteger {
                        from: 0;
                        to: 100;
                        duration: 500
                        running : scanningAnimation.visible
                        loops: Animation.Infinite
                    }
                }
                Image{
                    id: scanningBluetoothIcon
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "graphics/Bluetooth/Bluetooth_icon_medium.png"

                }
            }



            Item{
                id: btDeviceListBox
                visible: false
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                height: parent.height * 0.5

                Text{
                    id: btSelectDeviceText
                    text: "SELECT YOUR DEVICE:"
                    width: parent.width * 0.9
                    wrapMode: Text.WordWrap
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.bottom: bluetoothDeviceListBoxBrowser.top
                    anchors.bottomMargin: 5

                    color: "white"
                    font.bold: true
                    font.family: "sans serif"
                    font.pixelSize: parent.parent.height * 0.13
                }

                Item {
                    id: scanningAnimation2
                    height: 58
                    width: 108
                    anchors.right: bluetoothDeviceListBoxBrowser.left
                    anchors.rightMargin: 50
                    anchors.verticalCenter: bluetoothDeviceListBoxBrowser.verticalCenter
                    Image{
                        id: scanningBluetoothWave2
                        property int opacityInteger: 0
                        anchors.fill: parent
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                        source: "graphics/Bluetooth/Bluetooth_waves.png"
                        opacity: opacityInteger / 100.0
                        visible: waveAnimation.running
                        NumberAnimation on opacityInteger {
                            id: waveAnimation
                            from: 0;
                            to: 100;
                            duration: 500
                          //  running : bluetoothLEAdapter.scan()
                            loops: Animation.Infinite
                        }
                    }
                    ImageButton{
                        id: scanningBluetoothIcon2
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.horizontalCenter: parent.horizontalCenter
                        upimage: "graphics/Bluetooth/Bluetooth_icon_medium.png"
                        downimage: upimage
                        onClicked: if(!bluetoothAdapter.scanning) bluetoothLEAdapter.scan()
                    }
                }

                Rectangle {
                    id: bluetoothDeviceListBoxBrowser

                    color: "transparent"
                    radius: 10
                    width: parent.width * 0.5
                    height: parent.height * 0.7
                    anchors.bottom: parent.bottom
                    anchors.horizontalCenter: parent.horizontalCenter

                    //visible: !bluetoothAdapter.discovering && !bluetoothAdapter.connected && bluetoothDeviceList.model.count

                    ListView {
                        id: bluetoothDeviceList

                        clip: true
                        anchors.fill: parent
                        anchors.margins: 5
                        model: bluetoothLEAdapter.hrMonitors
                        highlight: Rectangle { color: "darkgray" ; radius: 5 ; opacity: 0.7 ; width: 400 }
                        highlightMoveSpeed: 1500
                        delegate: Component {
                            Item{
                                height: 40
                                width: parent.width
                                Text {
                                    text: name +" - "+ MAC
                                    color: "white"
                                    font.bold: true
                                    font.family: "sans serif"
                                    font.pixelSize: parent.height * 0.45
                                    verticalAlignment: Text.AlignVCenter
                                    horizontalAlignment: Text.AlignRight
                                    anchors.verticalCenter: parent.verticalCenter
                                    MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                           root.hrDeviceMAC= bluetoothLEAdapter.hrMonitors.get(index).MAC
                                            var name = bluetoothLEAdapter.hrMonitors.get(index).name
                                            bleHeartDialog.state = "monitoring"
                                            console.log("index = " + index)
                                            console.log("name mac"+ name + root.hrDeviceMAC )
                                            //item = bluetoothDeviceList.model.itemAt(index);
                                            bluetoothDeviceList.currentIndex = index
                                            brainboard.buzzerButtonPress()
                                            bluetoothLEAdapter.connecting = true
                                            bluetoothLEAdapter.getHrServiceHandle(root.hrDeviceMAC)

                                        }
                                    }
                                }
                            }
                        }
                    }
                }

                Column {
                    id: btDeviceListArrows

                    width: 40
                    height: 160
                    spacing: 50
                    visible: bluetoothDeviceList.model.count

                    anchors {   left: bluetoothDeviceListBoxBrowser.right;
                                verticalCenter: bluetoothDeviceListBoxBrowser.verticalCenter
                    }
                    Image {
                        id: dataUpArrow
                        source: "graphics/Swipe_Arrows_Left.png"
                        rotation: 90
                    }
                    Image {
                        id: dataDownArrow
                        source: "graphics/Swipe_Arrows_Left.png"
                        rotation: -90
                    }
                }
            }

//            Text {
//                id: btGettingPairingCodeText
//                visible: false
//                anchors.verticalCenter: parent.verticalCenter
//                anchors.horizontalCenter: parent.horizontalCenter
//                width: parent.width * 0.8
//                height: parent.height * 0.5
//                color: "white"
//                text: "GETTING PAIRING CODE..."
//                horizontalAlignment: Text.AlignHCenter
//                wrapMode: Text.WordWrap
//                font.bold: true
//                font.family: "sans serif"
//                font.pixelSize: parent.height * 0.15
//            }


            Text {
                id: btConnectingText
                visible: false
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                height: parent.height * 0.5
                color: "white"
                text: "CONNECTING TO BLUETOOTH DEVICE..."
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.15
            }

            Text {
                id: btDisconnectingText
                visible: false
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                height: parent.height * 0.5
                color: "white"
                text: "DISCONNECTING FROM BLUETOOTH DEVICE..."
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.15
            }

            ImageButton{
                id: btExitButton
                visible: false
                upimage: "Keypad/KeyPad_X.png"
                downimage: "Keypad/KeyPad_X.png"
                anchors.top: parent.top
                anchors.topMargin: 70
                anchors.right: parent.right
                anchors.rightMargin: 70
                onClicked: {
                    parent.state = "idle"
                    bleHeartDialog.hide()
                }
            }

        }


        states: [
            State{
                name: "idle"
                PropertyChanges {target: bleHeartDialog; visible: false}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: false}
                PropertyChanges {target: scanningAnimation; visible: false}
                PropertyChanges {target: btDisconnectingText; visible: false}



            },
            State{
                name: "scanning"
                PropertyChanges {target: bleHeartDialog; visible: true}
                PropertyChanges {target: btScanningText; visible: true}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: false}
                PropertyChanges {target: scanningAnimation; visible: true}
                PropertyChanges {target: btDisconnectingText; visible: false}

            },
            State{
                name: "monitorList"
                PropertyChanges {target: bleHeartDialog; visible: true}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: true}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: true}
                PropertyChanges {target: scanningAnimation; visible: false}
                PropertyChanges {target: btDisconnectingText; visible: false}
            },
            State{
                name: "monitoring"
                PropertyChanges {target: bleHeartDialog; visible: false}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: false}
                PropertyChanges {target: scanningAnimation; visible: false}
                PropertyChanges {target: btDisconnectingText; visible: false}
            },
            State{
                name: "connecting"
                PropertyChanges {target: bleHeartDialog; visible: true}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: true}
                PropertyChanges {target: btExitButton; visible: true}
                PropertyChanges {target: btDisconnectingText; visible: false}
            },
            State{
                name: "disconnecting"
                PropertyChanges {target: bleHeartDialog; visible: true}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: false}
                PropertyChanges {target: btDisconnectingText; visible: true}
            },
            State{
                name: "gettingpairingcode"
                PropertyChanges {target: bleHeartDialog; visible: true}
                PropertyChanges {target: btScanningText; visible: false}
                PropertyChanges {target: btDeviceListBox; visible: false}
                PropertyChanges {target: btConnectingText; visible: false}
                PropertyChanges {target: btExitButton; visible: false}
                PropertyChanges {target: btDisconnectingText; visible: false}
            }
        ]
    }


} // end heartRateCenter
