import QtQuick 1.1
import FileIO 1.0

Item {
    id: root

    property bool recording: false
    property bool copying: false
    property string recordFilename: ""

    function getRecordFilename() {
        var name = tv.getTVChannelName()
        if (!name)
            name = "unknown"
        var dateString = (new Date()).toISOString()
        // VLC cannot handle : in filename, so replace them with -
        dateString = dateString.replace(/:/g, "-")
        var filename = name + "-" + dateString + ".ts"
        return filename
    }

    function startRecording() {
        if (!storageMgr.usbDeviceLoaded) {
            needUsbDevicePopup.showWithTimeout(3)
            return
        }
        if (!tv.playing) {
            return
        }
        root.copying = false
        root.recording = true
        root.recordFilename = root.getRecordFilename()
        var savepath = "/tmp/"+recordFilename
        console.log("Starting TV recording...")
        console.log("Saving to", savepath)
        // testing TS stream capture
        tv.mrl += ":sout=#stream_out_duplicate{dst=display,dst=std{access=file,mux=ts,dst="+savepath+"}}"
    }

    function stopRecording() {
        console.log("Stopping TV recording...")
        tv.mrl = tv.mrl.replace(/:sout=#stream_out_duplicate{(.+)?}/, "")
        // Start copy from /tmp to USB key
        root.recording = false
        root.copying = true
        console.log("Starting copy")
        // give Qt events some time to process before blocking copy begins
        startCopyTimer.start()
    }

    Timer {
        id: startCopyTimer
        running: false
        repeat: false
        interval: 100
        onTriggered: {
            fileio.copy("/tmp/"+root.recordFilename, "/media/usb/"+root.recordFilename)
            syncDisk.start()
            root.copying = false
            fileio.remove("/tmp/"+root.recordFilename)
        }
    }

    FileIO {
        id: fileio
    }

    MessagePopup {
        id: needUsbDevicePopup
        message: qsTr("Insert USB device to record TV") + application.emptyString
    }
}
