// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1

Item {
    id: root

    property int volume: vol_setting
    property int percent: 100 * (volume / (vol_max - vol_min))
    property int vol_setting: 5
    onVol_settingChanged: console.log("vol>>", vol_setting)
    property int vol_max: 20
    property int vol_min: 0
    property alias muted: mute_button.isDown

    property string muteButtonDownimage: "graphics/224/224_Data_ToolBar_Round_Down.png"
    property string muteButtonUpimage: "graphics/224/224_Data_ToolBar_Round.png"
    property bool showSourceButton: false
    property string sourceIcon: ""

    signal sourceButtonClicked()

    width: 104
    height: childrenRect.height

    function volumeUp() {
      if(mute_button.isDown){
        mute_button.isDown = false
      }
      else{
        if(root.volume < root.vol_max)
          root.vol_setting++
      }
    }

    function volumeDown() {
      if(mute_button.isDown)
        mute_button.isDown = false
      else{
        if(root.volume > root.vol_min)
          root.vol_setting--
      }
    }

    ImageButton {
        id: volume_up_button

        repeat: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        icon: "graphics/netpulse/PLUS_icon_BLACK.png"
        upimage: "graphics/netpulse/UpArrow_gray.png"
        downimage: "graphics/netpulse/UpArrow_PRESSED.png"
        onClicked: {
            volumeUp();
        }
        mouseAreaScale: 1.25
    }

    // volume numeric display
    Text {
        id: volume_value


        text: root.volume
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_up_button.bottom
        anchors.topMargin: 0
        font.pixelSize: 30
    }

    ImageButton {
        id: volume_down_button

        repeat: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_value.bottom
        upimage: "graphics/netpulse/DownArrow_gray.png"
        downimage: "graphics/netpulse/DownArrow_PRESSED.png"
        icon: "graphics/netpulse/MINUS_icon_BLACK.png"
        icon_y_offset: -5

        onClicked: {
          volumeDown();
        }
        mouseAreaScale: 1.25
    }
    Text {
        id: volume_text
        text: qsTr("VOLUME") + application.emptyString
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: volume_down_button.bottom
        font.pixelSize: 14
    }
    ImageButton {
        id: mute_button
        property int y_offset: 0
        property int x_offset: 0

        anchors.top: volume_text.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: x_offset
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: "graphics/Media_Mute_Up.png"
        icon_x_offset: -x_offset
        icon_y_offset: -y_offset
        toggle: true
        mouseAreaScale: 1.25
    }

    ImageButton {
        id: source_button
        anchors.top: mute_button.bottom
        anchors.topMargin: 15
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 0
        downimage: muteButtonDownimage
        upimage: muteButtonUpimage
        icon: root.sourceIcon
        onClicked: {
            root.sourceButtonClicked()
        }

        mouseAreaScale: 1.25
        visible: root.showSourceButton
    }

    Text {
        id: change_source_text
        text: qsTr("CHANGE AUDIO") + application.emptyString
        font.bold: true
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: source_button.bottom
        font.pixelSize: 12
        visible: source_button.visible
    }

}
